@@ -56,9 +56,12 @@ class AWSProvider(BaseProvider):
         s3.Bucket(self.bucket_name).put_object(Key=key, Body=stream)
 
     def get_presigned_url(self, key, expiration=3600, method='get_object'):
+        resource_config = self.get_resource_config()
+
         s3 = boto3.client(
             's3',
-            **self.get_resource_config(),
+            **resource_config,
+            endpoint_url=f'https://s3.{resource_config["region_name"]}.amazonaws.com',
             config=Config(signature_version='s3v4')
         )
         response = s3.generate_presigned_url(
@@ -70,3 +73,33 @@ class AWSProvider(BaseProvider):
             ExpiresIn=expiration
         )
         return response
+
+    def list_objects(self, prefix='', delimiter=''):
+        s3 = boto3.client('s3', **self.get_resource_config())
+        object_names = []
+        next_continuation_token = None
+
+        while True:
+            extra_params = {}
+
+            if next_continuation_token:
+                extra_params['ContinuationToken'] = next_continuation_token
+
+
+            response = s3.list_objects_v2(
+                Bucket=self.bucket_name, Prefix=prefix, Delimiter=delimiter)
+
+            next_continuation_token = response.get('NextContinuationToken')
+
+            for object_data in response['Contents']:
+                if object_data['Size']:
+                    object_names.append(object_data['Key'])
+
+            for object_data in response.get('CommonPrefixes', []):
+                object_names.append(object_data['Prefix'])
+
+            if not next_continuation_token:
+                break
+
+
+        return object_names
